# Universal

Types:

```python
from isaacus.types.classifications.universal import UniversalClassificationResponse
```

Methods:

- <code title="post /classifications/universal">client.classifications.universal.<a href="./src/isaacus/resources/classifications/universal/universal.py">create</a>(\*\*<a href="src/isaacus/types/classifications/universal/universal_create_params.py">params</a>) -> <a href="./src/isaacus/types/classifications/universal/universal_classification_response.py">UniversalClassificationResponse</a></code>
